@@ -43,7 +43,6 @@ class ControllerRedShift:
         self.prefix = getenv("NODE_ENV") + '_'
         self.date_format= '%Y-%m-%dT%H:%M:%S'
 
-       
         # set self.url_string
         self.get_url()
 
@@ -54,7 +53,6 @@ class ControllerRedShift:
         self.logger.info("donde init method of ControllerRedShift ")
 
         """
-        
         engine = sa.create_engine(url)
         Session = sa_orm.sessionmaker()
         Session.configure(bind=engine)
@@ -66,10 +64,6 @@ class ControllerRedShift:
         # table_name
         # metadata
         # engine
-
-        
-
-        
         """
           
     def get_url(self):
@@ -221,7 +215,14 @@ class ControllerRedShift:
                         BETWEEN '{start}' and '{end}';"""
         return read_sql_query(text(sql),self.engine)
     
-    
+    def exists_user(self,user_uid):
+
+        sql = f"""
+                SELECT EXISTS (select 1 FROM dim_user
+                WHERE dim_user.user_uid = '{user_uid}');
+                """
+        return read_sql_query(text(sql),self.engine)
+      
     def select_nickname(self, start='2023-03-07 00:00:00', end = '2023-03-07 23:59:59'):        
 
         sql = f"""SELECT
@@ -252,7 +253,6 @@ class ControllerRedShift:
                         BETWEEN '{start}' and '{end}';"""
         return read_sql_query(text(sql),self.engine)
     
-    
     def exists(self, table_name,column_name ,value ):
 
         sql = "SELECT "+ column_name +" FROM " + table_name + " WHERE " + column_name + " = '"+ value +"';"
@@ -584,16 +584,18 @@ class ControllerRedShift:
                                                 transaction_uid,
                                                 user_uid,
                                                 account_uid,
-                                                amount
+                                                amount,
+                                                currency
                                                 )
-                        VALUES (%s,%s,%s,%s,%s)
+                        VALUES (%s,%s,%s,%s,%s,%s)
                                     '''
             record_to_insert = (
                         dict_values['transaction_date'],
                         dict_values['transaction_uid'],
                         dict_values['user_uid'],
                         dict_values['account_uid'],
-                        dict_values['amount']
+                        dict_values['amount'],
+                        dict_values['currency']
                                 )
             cur.execute(redshift_insert_query, record_to_insert)
             
